#
# spec file for package libosmo-netif
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libosmo-netif
Version:        1.6.0
Release:        1.3
Summary:        Osmocom library for muxed audio
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/Utilities
URL:            https://osmocom.org/projects/libosmo-netif
Source:         https://github.com/osmocom/libosmo-netif/archive/%version.tar.gz
Patch1:         osmo-talloc.diff
BuildRequires:  automake
BuildRequires:  libtool >= 2
BuildRequires:  lksctp-tools-devel
BuildRequires:  pkg-config >= 0.20
BuildRequires:  pkgconfig(libosmocodec) >= 1.11.0
BuildRequires:  pkgconfig(libosmocore) >= 1.11.0
BuildRequires:  pkgconfig(libosmogsm) >= 1.11.0
BuildRequires:  pkgconfig(talloc)

%description
Network interface demuxer library for OsmoCom projects.

%package -n libosmonetif11
Summary:        Osmocom library for muxed audio
License:        AGPL-3.0-or-later
Group:          System/Libraries

%description -n libosmonetif11
Network interface demuxer library for OsmoCom projects.

%package -n libosmonetif-devel
Summary:        Development files for the Osmocom muxed audio library
License:        AGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmonetif11 = %version

%description -n libosmonetif-devel
Network interface demuxer library for OsmoCom projects.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmo-netif.

%prep
%autosetup -p1

%build
echo "%version" >.tarball-version
autoreconf -fiv
# bugzilla.opensuse.org/795968 for rationale
%configure --includedir="%_includedir/%name" \
	--enable-shared --disable-static
%make_build

%install
%make_install
find "%buildroot/%_libdir" -type f -name "*.la" -delete

%check
if ! %make_build check; then
	rv=$?
	cat tests/testsuite.log
	echo "Suppressing exit $rv"
	# timing issue
fi

%ldconfig_scriptlets -n libosmonetif11

%files -n libosmonetif11
%_libdir/libosmonetif.so.*

%files -n libosmonetif-devel
%license COPYING
%dir %_includedir/%name/
%dir %_includedir/%name/osmocom/
%_includedir/%name/osmocom/netif/
%_libdir/libosmonetif.so
%_libdir/pkgconfig/libosmo-netif.pc

%changelog
* Thu Feb 13 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.0
  * Add osmo_stream_cli_set_{ip_dscp,priority}() APIs
  * Add osmo_stream_srv_link_set_{ip_dscp,priority}() APIs
  * Support destroy object within user callback
  * Add API osmo_stream_cli_set_tx_queue_max_length()
  * Add API osmo_stream_srv_link_set_tx_queue_max_length()
  * Fix discard 1st msg received quick after connect
  * Introduce osmo_stream_{cli,srv}_set_segmentation_cb2
  * Add osmo_stream_srv_link_set_msgb_alloc_info()
* Sat Oct 26 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.5.1
  * stream: Add client-side (segmentation) support for IPA
  * Introduce generic osmo_stream_{cli,srv}_get_fd() API
  * stream_{cli,srv}: Add support for SCTP in OSMO_IO mode
* Wed Nov  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.4.0
  * Add osmo_io support to osmo_stream_cli and osmo_stream_srv
  * ipa: Add segmentation callback
* Thu May 18 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.0
  * osmux: Introduce API osmux_xfrm_input_set_name
* Wed Aug  3 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.0
  * stream: Add support for AF_UNIX sockets
  * Introduce osmo_prim_srv APIs
  * prim: Add internal CTL SAPI to negotiate SAP versions
* Sun Mar 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.0
  * No changelog was provided
* Sun Sep  6 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.0
  * stream: Add new WAIT_RECONNECT cli state
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 0.7.0
  * libosmo-netif.pc.in: Append -lsctp to Libs.private
  * stream: osmo_stream_cli: Support setting multiple addr
  * stream: osmo_stream_srv_link: Support setting multiple addr
  * stream: Fix scheduling of queued messages during connecting state
  * stream: Introduce API osmo_stream_cli_is_connected
- Update patch
  * osmo-talloc.diff
* Thu Aug 15 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.6.0
  * osmux: Extend osmux_out_handle and add new API to set
    rtp payload_type
* Wed Feb 20 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 0.4.0
  * Bugfix release only.
    The full changelog is available via
    http://git.osmocom.org/libosmo-netif/plain/debian/changelog?h=0.4.0
- Rebase patch
  * osmo-talloc.diff
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.3.0
  * stream: Avoid re-creating and leaking socket when unneeded
  * osmo_stream_{cli,srv}_destroy: fix a mem leak on an empty msgb queue
  * Add support for flushing and destroying a server-side stream
  * jibuf: Add initial implementation of Jitter Buffer
  * Remove "channel" layer
* Wed Dec 27 2017 jengelh@inai.de
- Update to new upstream release 0.1.1
  * cosmetic: relax UDP length check
  * cosmetic: print textual error from recv()
  * osmux_snprintf: Support different types of Osmux frames
* Mon Oct  2 2017 jengelh@inai.de
- Update to new upstream snapshot 0.0.6.85
  * rtp: return offset in osmo_rtp_snprintf()
  * somo_stream_srv_fd_cb(): close socket if NODELAY fails
* Fri Apr 28 2017 jengelh@inai.de
- Update to new upstream snapshot 0.0.6.67
  * Fix potential NULL dereference
  * stream: don't crash in _close() when fd is not initialized
  * stream: When destroying, make sure to kill reconnect timer
  * osmux: Fix delay between RTP packets
* Sun Jul 31 2016 jengelh@inai.de
- Update to new upstream snapshot 0.0.6.19
  * misc: Drop oRTP dependency as there is nothing using it
  * osmux: Pass circuit to _batch_del_circuit() and use it from _xfrm_input_fini()
  * osmux: Add function to delete all msgs pending for a circuit
  * osmux-test: remove real-time constraint by default
* Tue Jan 26 2016 jengelh@inai.de
- Dump testsuite results on failure
* Fri Jan 22 2016 jengelh@inai.de
- Update to new upstream snapshot 0.0.6.8
  * don't link everything to libsctp
  * ensure to zero-initialize sctp_sndrcvinfo
* Wed Dec 23 2015 jengelh@inai.de
- Update to new upstream release 0.0.6.5
  * No changelog was provided
- Drop osmo-cppflags.diff, osmo-ldadd.diff, osmo-allincludes.diff
  (merged upstream)
* Thu Oct  2 2014 jengelh@inai.de
- Initial package (version 0.0.4) for build.opensuse.org
